@@ -9,7 +9,7 @@ from pybaselib.utils.pythrow.exceptions import GenErr, BadValue, ParameterError,
 from pybaselib.utils.appLayer.ntcip.ntcip_type_parameter import MessageMemoryType, \
     MessageStatus, ShortErrorStatusParameter, DmsMemoryMgmt, DmsControlMode, \
     GraphicStatus, GraphicType, FontStatus, DefaultLineJustification, \
-    DefaultPageJustification, DefaultCharacter
+    DefaultPageJustification, DefaultCharacter, DaylightSaving
 from pybaselib.utils.gitlab import Issue
 from pybaselib.utils.decorator.bug import deal_bug
 from pybaselib.utils.appLayer.udp.udp_client import UDPClient
