@@ -4,10 +4,12 @@
 # @Date: 2024/12/9 13:07
 
 import os
+import platform
 
 def ping_ip(ip):
-	res = os.system("ping {} -c 2".format(ip))
-	return True if res == 0 else False
+    param = "-n" if platform.system().lower() == "windows" else "-c"
+    res = os.system(f"ping {param} 2 {ip}")
+    return res == 0
 
 if __name__ == '__main__':
     # print(ping_ip('192.168.1.105'))
