@@ -58,3 +58,7 @@ DefaultPageJustification = DefaultPageJustificationParameter(1, 2, 3, 4)
 
 DefaultCharacterParameter = namedtuple('defaultCharacterSet', ['other', 'eightBit'])
 DefaultCharacter = DefaultCharacterParameter(1, 2)
+
+
+DaylightSavingParameter = namedtuple('globalDaylightSaving', ['other', 'disableDST', 'enableDST'])
+DaylightSaving = DaylightSavingParameter(1, 2, 3)
