@@ -2,5 +2,5 @@
 # @Author: maoyongfan
 # @email: maoyongfan@163.com
 # @Date: 2024/12/9 20:50
-from .snmpEngine import SnmpObject
+from .snmpEngine import SNMPManager
 from .smi_opr import SmiOpr
