@@ -28,13 +28,20 @@ class SNMPManager:
     def switch_to_central(self):
         self.port = self.central_port
 
+    def set_community(self, community):
+        self.community = community
+
     def deal_value(self, oid, value, prettyPrint, request_type):
         # print(" = ".join([x.prettyPrint() for x in (oid, value)]))
         logging.info(f"  {request_type} {oid.prettyPrint()} = {value.prettyPrint()}")
         logging.info(f"类型为：{type(value).__name__}")
 
         expect_rule = value.subtypeSpec
-        sub_expect_rule = expect_rule[-1]
+        if len(expect_rule) != 0:   # 由于expect_rule长度可能为0，增加下面代码
+            sub_expect_rule = expect_rule[-1]
+        else:
+            sub_expect_rule = expect_rule
+
         try:
             sub_expect_rule(value)
         except Exception as e:  # ValueConstraintError
@@ -76,7 +83,7 @@ class SNMPManager:
             # )
             if varBinds:
                 raise BugException("%s at %s" % (errorStatus.prettyPrint(),
-                                              errorIndex and varBinds[int(errorIndex) - 1][0] or "?",))
+                                                 errorIndex and varBinds[int(errorIndex) - 1][0] or "?",))
             else:
                 raise Exception("%s at %s" % (errorStatus.prettyPrint(), str(varBinds)))
         else:
@@ -96,7 +103,7 @@ class SNMPManager:
             if isinstance(value, str):
                 if mib[0] in ["dmsActivateMessage", "dmsGraphicTransparentColor", "dmsGraphicBlockBitmap",
                               "characterBitmap", "defaultBackgroundRGB", "defaultForegroundRGB", "dmsResetMessage",
-                              "dmsShortPowerRecoveryMessage", "dmsCommunicationsLossMessage","dmsEndDurationMessage"]:
+                              "dmsShortPowerRecoveryMessage", "dmsCommunicationsLossMessage", "dmsEndDurationMessage"]:
                     value = OctetString(hexValue=value)
                 else:
                     value = OctetString(value)
@@ -254,23 +261,38 @@ class SNMPManager:
             logging.info(result)
             return result
 
-    async def next_cmd_single_mib(self, object_type, index=0, mib_name="NTCIP1203v03f-MIB", prettyPrint=False):
+    async def next_cmd(self, object_type, index=0, mib_name="NTCIP1203v03f-MIB", prettyPrint=False, get_oid=None,
+                       response="value"):
         mib_name = self.deal_mib_name(mib_name)
+        if get_oid is None:
+            from pysnmp.smi import builder, view, compiler
+            mibBuilder = builder.MibBuilder()
+            mibViewController = view.MibViewController(mibBuilder)
+            obj = ObjectType(ObjectIdentity(mib_name, object_type, index))
+            get_oid = (obj.resolve_with_mib(mibViewController))[0].get_oid()
+            logging.info(f"get_next请求oid为: {get_oid}")
+        else:
+            obj = ObjectType(ObjectIdentity(get_oid))
         errorIndication, errorStatus, errorIndex, varBinds = await next_cmd(
             SnmpEngine(),
             CommunityData(self.community, mpModel=1),
             await UdpTransportTarget.create((self.ipaddr, self.port)),
             ContextData(),
-            ObjectType(ObjectIdentity(mib_name, object_type, index)),
+            obj,
             # lexicographicMode=True,
         )
 
         self.deal_error(errorIndication, errorStatus, errorIndex, varBinds)
 
         for oid, value in varBinds:
+            logging.info(f"get_next返回oid为: {oid}")
+            print(f"get_next返回oid为: {oid}")
             result = self.deal_value(oid, value, prettyPrint, "next-request")
             logging.info(result)
-            # return result
+            if response == "oid":
+                return get_oid, oid
+            else:
+                return result
 
     async def bulk_cmd(self, nonRepeaters, maxRepetitions, varBinds, prettyPrint=False):
         resultList = []
@@ -296,7 +318,9 @@ class SNMPManager:
 
 
 if __name__ == "__main__":
-    snmpObject = SNMPManager("192.168.1.121")  # 192.168.1.105 192.168.1.120
+    snmpObject = SNMPManager("192.168.1.138")  # 192.168.1.105 192.168.1.120
+    asyncio.run(snmpObject.next_cmd(None))
+    # asyncio.run(snmpObject.next_cmd(None, oid="1.3.6.1.4.1.1206.4.2.3.1.1.0"))
     # asyncio.run(snmpObject.get_cmd_many([
     #     ObjectType(ObjectIdentity("1.3.6.1.4.1.1206.4.2.3.3.1.0")),
     #     ObjectType(ObjectIdentity("1.3.6.1.4.1.1206.4.2.3.6.8.0"))]))
@@ -304,7 +328,7 @@ if __name__ == "__main__":
     # a = [("dmsMaxChangeableMsg", 0), ("dmsFreeChangeableMemory", 0)]
     # result = asyncio.run(snmpObject.get_cmd_many_mib(a))
 
-    asyncio.run(snmpObject.get_cmd_single_mib("dmsMessageStatus", 3, 1))
+    # asyncio.run(snmpObject.get_cmd_single_mib("dmsMessageStatus", 3, 1))
     # asyncio.run(snmpObject.get_cmd_single("1.3.6.1.4.1.1206.4.2.3.3.1.0"))
     # 字体名称
     # print("返回",asyncio.run(snmpObject.get_cmd_single("1.3.6.1.4.1.1206.4.2.3.3.2.1.3.3")))
