@@ -4,8 +4,10 @@
 # @Date: 2025/2/28 23:05
 
 import datetime
-from datetime import timezone
+from datetime import timezone, timedelta
 import time
+import calendar
+
 
 def get_utc_seconds():
     """
@@ -14,15 +16,18 @@ def get_utc_seconds():
     """
     return int(datetime.datetime.now(timezone.utc).timestamp())
 
+
 def get_strftime():
     """
 		获取当前格式化时间
 	"""
     return datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
 
+
 def get_timestamp():
     return datetime.datetime.now().strftime("%Y%m%d_%H%M%S")
 
+
 def get_localTime():
     return datetime.datetime.now()
 
@@ -200,3 +205,84 @@ def timeDifference_seconds(startTime, endTime, return_type: str):
         return int(total_seconds / 60 / 60)
     else:
         return int(total_seconds / 60 / 60 / 24)
+
+
+def get_second_sunday_march_utc_timestamp(year):
+    # 计算3月1日是星期几（0=Monday, 6=Sunday）
+    march_first = datetime.datetime(year, 3, 1)
+    first_weekday = march_first.weekday()
+
+    # 找到当年3月的第一个星期日（6是Sunday）
+    first_sunday_offset = (6 - first_weekday) % 7
+    first_sunday = march_first + timedelta(days=first_sunday_offset)
+
+    # 第二个星期日
+    second_sunday = first_sunday + timedelta(weeks=1)
+
+    # 构造目标时间（凌晨1:58）
+    target_time = second_sunday.replace(hour=1, minute=58)
+
+    # 将其视为本地时间，转换为 UTC 时间戳（秒数）
+    utc_timestamp = calendar.timegm(target_time.utctimetuple())
+    return int(utc_timestamp) - 28800
+
+
+def get_second_sunday_march_timestamp(year, timezone_str):
+    """
+    计算某一年对应的三月第二个星期日凌晨 1:58 的当地时间（以秒为单位）
+    :param year:
+    :return:
+    """
+    from zoneinfo import ZoneInfo
+    # 获取时区对象（自动处理夏令时）
+    local_zone = ZoneInfo(timezone_str)
+
+    # 三月一日
+    march_first = datetime.datetime(year, 3, 1)
+
+    # 计算第一周的星期日
+    first_weekday = march_first.weekday()  # 0 = Monday
+    first_sunday_offset = (6 - first_weekday) % 7
+    first_sunday = march_first + timedelta(days=first_sunday_offset)
+
+    # 第二个星期日
+    second_sunday = first_sunday + timedelta(weeks=1)
+
+    # 构造当地时间：凌晨 1:58（含时区信息）
+    local_time = datetime.datetime(year, 3, second_sunday.day, 1, 58, tzinfo=local_zone)
+
+    # 转换为 UTC 时间
+    utc_time = local_time.astimezone(ZoneInfo("UTC"))
+
+    # 返回 UTC 秒数（1970-01-01 00:00:00 UTC 起的秒数）
+    return calendar.timegm(utc_time.timetuple())
+
+
+
+def timestamp_to_local_time(timestamp):
+    local_time = datetime.datetime.fromtimestamp(timestamp)
+    return local_time
+
+
+def get_nov_first_sunday_timestamp(year):
+    # 从11月1日开始
+    nov1 = datetime.datetime(year, 11, 1)
+    # 找出11月第一个星期日的偏移天数
+    days_to_sunday = (6 - nov1.weekday()) % 7
+    first_sunday = nov1 + timedelta(days=days_to_sunday)
+
+    # 构建1:58时间点
+    dt = datetime.datetime(year, 11, first_sunday.day, 1, 58)
+
+    # 转换为当地时间戳
+    timestamp = int(time.mktime(dt.timetuple()))
+    return timestamp - 28800
+
+if __name__ == "__main__":
+    a = get_second_sunday_march_timestamp(2025, "Asia/Shanghai")
+    print(a)
+    b = get_second_sunday_march_utc_timestamp(2025)
+    print(b)
+    print(timestamp_to_local_time(b))
+    c = get_nov_first_sunday_timestamp(2025)
+    print(timestamp_to_local_time(c))
